%Create picture of local asymptotic shrinkage function g(Y)
clear
close all
Y=[-4:0.2:-0.2]';
Y=[Y;-flipud(Y)];
randn('seed',123);
replics=10^6; 
n=1000;
lambda=2*log(0.5);
g1=abs(Y)>sqrt(2);
g2=1-normcdf(sqrt(2)-Y)+(normpdf(sqrt(2)-Y)./Y)+normcdf(-sqrt(2)-Y)-(normpdf(-sqrt(2)-Y)./Y);
h1=1-normcdf(2-Y)-(normpdf(2-Y)./Y)+normcdf(-2-Y)+(normpdf(-2-Y)./Y);
h2=1-normcdf(sqrt(2)-(sqrt(0.5)*Y))+normcdf(-sqrt(2)-(sqrt(0.5)*Y));
j1=max((2*Y.*Y)+lambda,0);
j1=sqrt(j1);
j1=normcdf(j1-Y)-normcdf(-j1-Y);
stat=zeros(length(Y),replics);
for j=1:replics;
    z=randn(1,1);
    r=2*((Y+z).^2);
    r=max(r+lambda,0);
    stat(:,j)=(Y+z).*(normcdf(sqrt(r)-Y-z)-normcdf(-sqrt(r)-Y-z))./Y;
end;
j2=mean(stat')';
plot(Y,g1,'k:','Linewidth',2);
hold on
plot(Y,g2,'k-','Linewidth',2);
plot(Y,h1,'r:','Linewidth',2);
plot(Y,h2,'r-','Linewidth',2);
plot(Y,j1,'b:','Linewidth',2);
plot(Y,j2,'b-','Linewidth',2);
line([-4 4],[0 0],'Color','k');
hleg1=legend({'AIC/AICRB','AICB','SSRB','SSB','OOSRB','OOSB'});
set(hleg1,'Location','North');
set(gca,'fontsize',14)
xlabel('Y','Fontsize',14);
ylabel('g(Y)','Fontsize',14);


%----Verification by direct simulation---%
clear
randn('seed',123);
Y=[-4:0.2:-0.2]';
Y=[Y;-flipud(Y)];
f1=abs(Y)>sqrt(2);
replics=10^6; 
for imc=1:replics;
    cu=sqrt(0.25)*randn(1,1); cv1=sqrt(0.5)*randn(1,1); cv2=cv1+(sqrt(0.5)*randn(1,1));
    Ypi=(0.5*Y)+cu;
    g1(:,imc)=(2*(Y-Ypi)./Y).*(abs(Ypi)>1);
    Y1=Y+cv2;
    Ypi=(0.5*Y)+cv1;
    f2(:,imc)=(abs(Y1)>sqrt(2)).*(Y1./Y);
    g2(:,imc)=(2*(Y1-Ypi)./Y).*(abs(Ypi)>1);
    Ypi=(0.5*Y)+cu;
    h1(:,imc)=(Y.^2)-(2*(Ypi.^2))+log(0.5)>0;
    Y1=Y+cv2;
    Ypi=(0.5*Y)+cv1;
    h2(:,imc)=((Y1.^2)-(2*(Ypi.^2))+log(0.5)>0).*(Y1./Y);
end;
f2=mean(f2');
g1=mean(g1')';
g2=mean(g2')';
h1=mean(h1')';
h2=mean(h2')';
figure(2);
plot(Y,f1,'k:','Linewidth',2);
hold on;
plot(Y,f2,'k-','Linewidth',2);
plot(Y,g1,'r:','Linewidth',2);
plot(Y,g2,'r-','Linewidth',2);
plot(Y,h1,'b:','Linewidth',2);
plot(Y,h2,'b-','Linewidth',2);
legend({'AIC/AICRB','AICB','SSRB','SSB','OOSRB','OOSB'});